@@ -12,6 +12,7 @@ from typing import TYPE_CHECKING, Any, Callable, Dict, List, Optional, Union
 
 import packaging
 import subprocess_tee
+from packaging.version import Version
 
 from ansible_compat.config import (
     AnsibleConfig,
@@ -36,6 +37,8 @@ else:
     CompletedProcess = subprocess.CompletedProcess
 
 _logger = logging.getLogger(__name__)
+# regex to extract the first version from a collection range specifier
+version_re = re.compile(":[>=<]*([^,]*)")
 
 
 class Runtime:
@@ -79,6 +82,12 @@ class Runtime:
         self.isolated = isolated
         self.max_retries = max_retries
         self.environ = environ or os.environ.copy()
+        # Reduce noise from paramiko, unless user already defined PYTHONWARNINGS
+        # paramiko/transport.py:236: CryptographyDeprecationWarning: Blowfish has been deprecated
+        # https://github.com/paramiko/paramiko/issues/2038
+        if "PYTHONWARNINGS" not in self.environ:
+            self.environ["PYTHONWARNINGS"] = "ignore::CryptographyDeprecationWarning"
+
         if isolated:
             self.cache_dir = get_cache_dir(self.project_dir)
         self.config = AnsibleConfig()
@@ -207,6 +216,13 @@ class Runtime:
         if force or self.version_in_range(upper="2.11"):
             cmd.append("--force")
 
+        # As ansible-galaxy install is not able to automatically determine
+        # if the range requires a pre-release, we need to manuall add the --pre
+        # flag when needed.
+        matches = version_re.search(collection)
+        if matches and Version(matches[1]).is_prerelease:
+            cmd.append("--pre")
+
         if destination:
             cmd.extend(["-p", str(destination)])
         cmd.append(f"{collection}")
@@ -301,12 +317,24 @@ class Runtime:
         required_collections: Optional[Dict[str, str]] = None,
         retry: bool = False,
         install_local: bool = False,
+        offline: bool = False,
+        role_name_check: int = 0,
     ) -> None:
         """Make dependencies available if needed."""
         if required_collections is None:
             required_collections = {}
 
-        self.install_requirements("requirements.yml", retry=retry)
+        if not offline:
+            # first one is standard for collection layout repos and the last two
+            # are part of Tower specification
+            # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#ansible-galaxy-support
+            # https://docs.ansible.com/ansible-tower/latest/html/userguide/projects.html#collections-support
+            for req_file in [
+                "requirements.yml",
+                "roles/requirements.yml",
+                "collections/requirements.yml",
+            ]:
+                self.install_requirements(req_file, retry=retry)
 
         destination = f"{self.cache_dir}/collections" if self.cache_dir else None
         for name, min_version in required_collections.items():
@@ -331,7 +359,9 @@ class Runtime:
             self.install_collection_from_disk("../..", destination=destination)
         else:
             # no collection, try to recognize and install a standalone role
-            self._install_galaxy_role(self.project_dir, ignore_errors=True)
+            self._install_galaxy_role(
+                self.project_dir, role_name_check=role_name_check, ignore_errors=True
+            )
 
     def require_collection(  # noqa: C901
         self,
@@ -390,7 +420,7 @@ class Runtime:
                 break
         else:
             if install:
-                self.install_collection(f"{name}:>={version}")
+                self.install_collection(f"{name}:>={version}" if version else name)
                 self.require_collection(name=name, version=version, install=False)
             else:
                 msg = f"Collection '{name}' not found in '{paths}'"
@@ -436,6 +466,20 @@ class Runtime:
         if roles_path != self.config.default_roles_path:
             self._update_env("ANSIBLE_ROLES_PATH", roles_path)
 
+    def _get_roles_path(self) -> pathlib.Path:
+        """Return roles installation path.
+
+        If `self.isolated` is set to `True`, `self.cache_dir` would be
+        created, then it returns the `self.cache_dir/roles`. When `self.isolated` is
+        not mentioned or set to `False`, it returns the first path in
+        `default_roles_path`.
+        """
+        if self.cache_dir:
+            path = pathlib.Path(f"{self.cache_dir}/roles")
+        else:
+            path = pathlib.Path(os.path.expanduser(self.config.default_roles_path[0]))
+        return path
+
     def _install_galaxy_role(
         self, project_dir: str, role_name_check: int = 0, ignore_errors: bool = False
     ) -> None:
@@ -484,16 +528,19 @@ class Runtime:
                 fqrn = f"{role_namespace}{role_name}"
             else:
                 fqrn = pathlib.Path(project_dir).absolute().name
-        path = pathlib.Path(os.path.expanduser(self.config.default_roles_path[0]))
+        path = self._get_roles_path()
         path.mkdir(parents=True, exist_ok=True)
         link_path = path / fqrn
         # despite documentation stating that is_file() reports true for symlinks,
         # it appears that is_dir() reports true instead, so we rely on exists().
         target = pathlib.Path(project_dir).absolute()
-        exists = link_path.exists() or link_path.is_symlink()
-        if not exists or os.readlink(link_path) != str(target):
-            if link_path.exists():
-                link_path.unlink()
+        if not link_path.exists() or (
+            link_path.is_symlink() and os.readlink(link_path) != str(target)
+        ):
+            # must call unlink before checking exists because a broken
+            # link reports as not existing and we want to repair it
+            link_path.unlink(missing_ok=True)
+            # https://github.com/python/cpython/issues/73843
             link_path.symlink_to(str(target), target_is_directory=True)
         _logger.info(
             "Using %s symlink to current repository in order to enable Ansible to find the role using its expected full name.",
